@@ -3,7 +3,7 @@
    Copyright (C) 2018-2021 Aamot Software
    Author(s): Ole Aamot <ole@gnome.org>
    License: GNU GPL version 3
-   Version: 2.0.1 (2021-10-25)
+   Version: 3.0.0 (2021-11-21)
    Website: http://www.gingerblue.org/
 
  */
@@ -210,6 +210,11 @@ static void gb_assistant_apply(GtkAssistant * assistant, gpointer data)
 	gst_element_send_event(data, gst_event_new_eos());
 }
 
+static void gb_record_cb (char *path, gpointer data)
+{
+        return;
+}
+
 GtkAssistantPageFunc gb_assistant_cb(GtkAssistant * assistant,
 				     GDateTime * datestamp)
 {
