@@ -3,13 +3,18 @@
    Copyright (C) 2018-2021 Aamot Software
    Author(s): Ole Aamot <ole@gnome.org>
    License: GNU GPL version 3
-   Version: 2.0.1 (2021-10-25)
+   Version: 3.0.0 (2021-11-21)
    Website: http://www.gingerblue.org/
    
 */
 
+#ifndef GINGERBLUE_SONG_H
+#define GINGERBLUE_SONG_H 1
+
 #include <libxml/xmlmemory.h>
 #include <libxml/parser.h>
 
 GtkWidget *gb_song_new (gchar *title);
 GtkWidget *gb_song_quit (gchar *title);
+
+#endif /* GINGERBLUE_SONG_H */
